/**
 * This file is part of the NocoBase (R) project.
 * Copyright (c) 2020-2024 NocoBase Co., Ltd.
 * Authors: NocoBase Team.
 *
 * This project is dual-licensed under AGPL-3.0 and NocoBase Commercial License.
 * For more information, please refer to: https://www.nocobase.com/agreement.
 */
/// <reference types="react" />
import { SchemaInitializerItemType } from '@nocobase/client';
import { RadioWithTooltip } from '../components/RadioWithTooltip';
import { WorkflowVariableTextArea } from '../variable';
import { Instruction } from '.';
export default class extends Instruction {
    title: string;
    type: string;
    group: string;
    description: string;
    fieldset: {
        engine: {
            type: string;
            title: string;
            'x-decorator': string;
            'x-component': string;
            'x-component-props': {
                options: any;
            };
            required: boolean;
            default: string;
        };
        expression: {
            type: string;
            title: string;
            'x-decorator': string;
            'x-component': string;
            'x-component-props': {
                changeOnSelect: boolean;
            };
            "x-validator"(value: any, rules: any, { form }: {
                form: any;
            }): string;
            'x-reactions': {
                dependencies: string[];
                fulfill: {
                    schema: {
                        description: string;
                    };
                };
            }[];
            required: boolean;
        };
    };
    scope: {
        renderEngineReference: (key: string) => import("react").JSX.Element;
    };
    components: {
        WorkflowVariableTextArea: typeof WorkflowVariableTextArea;
        RadioWithTooltip: typeof RadioWithTooltip;
        ValueBlock: (() => JSX.Element) & {
            Initializer: () => JSX.Element;
            Result: (props: any) => JSX.Element;
            Designer: () => JSX.Element;
        };
    };
    useVariables({ key, title }: {
        key: any;
        title: any;
    }, { types, fieldNames }: {
        types: any;
        fieldNames?: {
            readonly label: "label";
            readonly value: "value";
            readonly children: "children";
        };
    }): {
        value: any;
        label: any;
    };
    useInitializers(node: any): SchemaInitializerItemType;
}
