/**
 * This file is part of the NocoBase (R) project.
 * Copyright (c) 2020-2024 NocoBase Co., Ltd.
 * Authors: NocoBase Team.
 *
 * This project is dual-licensed under AGPL-3.0 and NocoBase Commercial License.
 * For more information, please refer to: https://www.nocobase.com/agreement.
 */
import { ISchema } from '@formily/react';
import React from 'react';
import { SchemaInitializerItemType } from '@nocobase/client';
import WorkflowPlugin from '..';
import { UseVariableOptions, VariableOption } from '../variable';
export type NodeAvailableContext = {
    engine: WorkflowPlugin;
    workflow: object;
    upstream: object;
    branchIndex: number;
};
export declare abstract class Instruction {
    title: string;
    type: string;
    group: string;
    description?: string;
    /**
     * @experimental
     */
    options?: {
        label: string;
        value: any;
        key: string;
    }[];
    fieldset: {
        [key: string]: ISchema;
    };
    /**
     * @experimental
     */
    view?: ISchema;
    scope?: {
        [key: string]: any;
    };
    components?: {
        [key: string]: any;
    };
    Component?(props: any): JSX.Element;
    /**
     * @experimental
     */
    createDefaultConfig?(): Record<string, any>;
    useVariables?(node: any, options?: UseVariableOptions): VariableOption;
    useScopeVariables?(node: any, options?: any): VariableOption[];
    useInitializers?(node: any): SchemaInitializerItemType | null;
    /**
     * @experimental
     */
    isAvailable?(ctx: NodeAvailableContext): boolean;
    end?: boolean | ((node: any) => boolean);
}
export declare const NodeContext: React.Context<any>;
export declare function useNodeContext(): any;
export declare function useNodeSavedConfig(keys?: any[]): boolean;
/**
 * @experimental
 */
export declare function useAvailableUpstreams(node: any, filter?: any): any[];
/**
 * @experimental
 */
export declare function useUpstreamScopes(node: any): any[];
export declare function Node({ data }: {
    data: any;
}): React.JSX.Element;
export declare function RemoveButton(): React.JSX.Element;
export declare function JobButton(): React.JSX.Element;
export declare function NodeDefaultView(props: any): React.JSX.Element;
